%define srcname	LibreCAD

%define dxfrw_includedir %(pkg-config --cflags-only-I libdxfrw0 | sed 's|-I||g')

Name:		librecad
Summary:	An generic 2D CAD program
Version:	2.1.3
Release:	%mkrel 1
Group:		Graphics/3D
License:	GPLv2
URL:		http://www.librecad.org/
Source0:	https://github.com/LibreCAD/LibreCAD/archive/%{version}/%{srcname}-%{version}.tar.gz
# Originally from Fedora:
Patch0:		LibreCAD-2.0.8-use-system-shapelib.patch
Patch1:		LibreCAD-2.1.1-use-system-libdxfrw.patch
BuildRequires:	boost-devel
BuildRequires:	muparser-devel
BuildRequires:	shapelib-devel
BuildRequires:	libdxfrw-devel >= 0.6.3-4
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	qt5clucene-devel
BuildRequires:	qttools5
Recommends:	%{name}-data
Recommends:	%{name}-parts
Recommends:	%{name}-doc
Recommends:	%{name}-plugins

%description
LibreCAD is a Qt5 application to design 2D cad drawing based on the community
edition of QCad.

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/mime/packages/*.xml
%{_datadir}/pixmaps/%{name}.png

#-----------------------------------------------------------------------------

%package	data
Summary:	Data platform independent files for %{name}
Requires:	%{name}
BuildArch:	noarch

%description	data
LibreCAD is an application for computer aided design (CAD) in two
dimensions (2D).

This package contains plataform independent files for LibreCAD, including
fonts, patterns, and interface translations.

%files		data
%{_datadir}/%{name}/qm/
%{_datadir}/%{name}/fonts/
%{_datadir}/%{name}/patterns/

#------------------------------------------------------------------------------

%package	parts
Summary:	Parts collection for %{name}
Requires:	%{name}
BuildArch:	noarch


%description	parts
Collection of parts for %{name}, a Qt5 application to design 2D cad drawing
based on the community edition of QCad.

%files		parts
%{_datadir}/%{name}/library

#------------------------------------------------------------------------------

%package	plugins
Group:		Graphics/3D
Summary:	Plugins libraries files for %{name}
Requires:	%{name}

%description	plugins
Contains the plugins files for LibreCAD.

%files		plugins
%{_libdir}/%{name}/plugins/

#------------------------------------------------------------------------------

%package	doc
Summary:	Documentation for %{name}
BuildArch:	noarch
Conflicts:	librecad < 1.0.0-0.rc2

%description	doc
LibreCAD is an application for computer aided design (CAD) in two dimensions
(2D).

This package contains documentation for LibreCAD.
%files		doc
%doc README.md
%doc %{_datadir}/doc/%{name}/html/

#------------------------------------------------------------------------------

%prep
%setup -qn %{srcname}-%{version}
%autopatch -p1

echo 'MUPARSER_DIR = %{_prefix}' >> settings_linux.pro
echo 'BOOST_DIR = %{_includedir}' >> settings_linux.pro
echo 'BOOST_LIBDIR = %{_libdir}' >> settings_linux.pro

sed -i 's|$${DXFRW_INCLUDEDIR}|%{dxfrw_includedir}|g' librecad/src/src.pro

# drop bundled libs and use system ones
rm -rf plugins/importshp/shapelib
rm -rf libraries/libdxfrw
rm -rf libraries/muparser

%build
export PATH=%_qt5_bindir:$PATH
%qmake_qt5 librecad.pro
%make

%install
# Let's create the directory structure
%__install -d %{buildroot}%{_datadir}/%{name}/{fonts,patterns,qm,library/misc,library/templates,doc}
%__install -d %{buildroot}%{_datadir}/doc/%{name}/html/{classref/html/,img,imgs}
%__install -d %{buildroot}%{_datadir}/applications/
%__install -d %{buildroot}%{_libdir}/%{name}/plugins

# Now install all files
%__install -Dm 755 unix/%{name} %{buildroot}/%{_bindir}/%{name}
%__install -Dm 644 librecad/res/main/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%__install -t %{buildroot}%{_datadir}/%{name}/patterns/ unix/resources/patterns/*.dxf
%__install -t %{buildroot}%{_datadir}/%{name}/fonts/ unix/resources/fonts/*
%__install -t %{buildroot}%{_datadir}/%{name}/library/misc unix/resources/library/misc/*
%__install -t %{buildroot}%{_datadir}/%{name}/library/templates unix/resources/library/templates/*
%__install -t %{buildroot}%{_datadir}/%{name}/qm/  unix/resources/qm/*.qm
%__install -t %{buildroot}%{_libdir}/%{name}/plugins/ unix/resources/plugins/*

# Install documentation files
%__install -t %{buildroot}%{_datadir}/doc/%{name}/html librecad/support/doc/*.html

# appdata
install -Dpm644 librecad/support/librecad.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

# Create the desktop file
mkdir -p  %{buildroot}%{_datadir}/applications/
desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--add-category="Qt" \
	--remove-mime-type="image/vnd.dxf" \
	--add-mime-type="image/vnd.dxf" \
		desktop/librecad.desktop

install -m0644 -D desktop/librecad.sharedmimeinfo %{buildroot}%{_datadir}/mime/packages/%{name}.xml

%find_lang %{name}


%changelog
* Sun Jan 08 2017 wally <wally> 2.1.3-1.mga6
+ Revision: 1080620
- new version 2.1.3
- drop upstreamed patches

* Thu Aug 18 2016 wally <wally> 2.1.1-2.mga6
+ Revision: 1046840
- new version 2.1.1
- sync patches with Fedora

* Sat May 14 2016 wally <wally> 2.0.10-1.mga6
+ Revision: 1015394
- new version 2.0.10

* Sat Mar 05 2016 wally <wally> 2.0.9-1.mga6
+ Revision: 986047
- new version 2.0.9

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Oct 25 2015 wally <wally> 2.0.8-3.mga6
+ Revision: 895425
- rebuild to fix segfault with new libdxfrw

* Sun Aug 23 2015 wally <wally> 2.0.8-2.mga6
+ Revision: 868299
- add patch originally from Fedora to build with system libdxfrw

* Sun Aug 23 2015 wally <wally> 2.0.8-1.mga6
+ Revision: 868272
- new version 2.0.8
- drop upstreamed patches
- switch to Qt5

* Wed Jan 07 2015 alexl <alexl> 2.0.5-5.mga5
+ Revision: 808981
- added GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 2.0.5-4.mga5
+ Revision: 742786
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.5-3.mga5
+ Revision: 681752
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sun Sep 14 2014 alexl <alexl> 2.0.5-2.mga5
+ Revision: 675476
- translated desktop file (i18n-desktop.patch)

* Thu Aug 28 2014 wally <wally> 2.0.5-1.mga5
+ Revision: 669090
- new version 2.0.5
- install appdata file

* Sat Jun 07 2014 wally <wally> 2.0.4-2.mga5
+ Revision: 634303
- rediff shapelib patch after latest shapelib changes

* Sat Jun 07 2014 wally <wally> 2.0.4-1.mga5
+ Revision: 634270
- new version 2.0.4
- add patch from Fedora to use system shapelib

* Fri Jun 06 2014 wally <wally> 2.0.3-2.mga5
+ Revision: 634200
- rebuild for new muparser

* Sat May 17 2014 sander85 <sander85> 2.0.3-1.mga5
+ Revision: 623185
- New version: 2.0.3

* Thu Mar 06 2014 akien <akien> 2.0.2-1.mga5
+ Revision: 600481
- New version 2.0.2

* Sat Oct 19 2013 umeabot <umeabot> 2.0.0-0.rc1.2.mga4
+ Revision: 531547
- Mageia 4 Mass Rebuild

* Mon Aug 05 2013 fwang <fwang> 2.0.0-0.rc1.1.mga4
+ Revision: 463943
- update file list
- update file list
- update file list
- update pixmap file location
- fix build within moc
- update settings switch
- br boost
- new version 2.0.0rc1

* Sat Jan 12 2013 umeabot <umeabot> 1.0.2-3.mga3
+ Revision: 358088
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 30 2012 ovitters <ovitters> 1.0.2-2.mga3
+ Revision: 323446
- fix rpm group

* Sat Jun 16 2012 fwang <fwang> 1.0.2-1.mga3
+ Revision: 260984
- br muparser
- new version 1.0.2
- lcms 2 is not needed

* Fri Jan 20 2012 schultz <schultz> 1.0.0-1.mga2
+ Revision: 198733
- fix plugins subpackge filelist
- Update to 1 final
- fix file list
- fix install

* Sat Oct 29 2011 fwang <fwang> 1.0.0-0.rc4.1.mga2
+ Revision: 159715
- new version 1.0 rc4

* Sat Oct 01 2011 fwang <fwang> 1.0.0-0.rc3.1.mga2
+ Revision: 150703
- updated to rc3

* Sun Sep 25 2011 mikala <mikala> 1.0.0-0.rc2.1.mga2
+ Revision: 147585
- Fix .desktop creation
- remove rm -rf %%buildroot from %%install (not needed anymore)
- Remove %%defattr() & %%clean section
- fix Release tag

  + schultz <schultz>
    - Use pkgconfig
      Fix some doc issues
    - Fix file confict - README moved to doc package
      Add plugin package
    - remove rs_debug.patch
    - Remove beta5 tarball
    - Remove rs_debug patch, not needed anymore
      Add rs_ellipse patch - fixes build
      Update to RC2

* Mon May 02 2011 mikala <mikala> 1.0.0-0.beta5.mga1
+ Revision: 94283
- imported package librecad

